@@ -8,11 +8,11 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = "2.003";
+our $VERSION = "2.004";
 $VERSION = eval $VERSION;
 
 use LWP::UserAgent;
-use IO::Socket::SSL;
+use LWP::Protocol::https;
 use DateTime qw();
 use base 'SMS::Send::Driver';
 use Log::LogLite;
@@ -84,11 +84,6 @@ sub send_sms {
 	}
 	
 	# send away
-    IO::Socket::SSL::set_ctx_defaults(
-         SSL_verifycn_scheme => 'www',
-         SSL_verify_mode => 0,
-    );
-
     my $ua = LWP::UserAgent->new(ssl_opts => { verify_hostname => 0 });
     $ua->protocols_allowed( ['https'] );
     my $res = $ua->post($url, \%params );
@@ -123,7 +118,7 @@ SMS::Send::CZ::Bulkgate - SMS::Send driver for Bulkgate - Czech Republic
 
 =head1 VERSION
 
-version 2.003
+version 2.004
 
 =head1 SYNOPSIS
 
